@@ -1,7 +1,6 @@
 package App::BorgRestore::DB;
 use v5.14;
-use strict;
-use warnings;
+use strictures 2;
 
 use App::BorgRestore::Helper;
 
@@ -28,11 +27,14 @@ method new($class: $db_path, $cache_size) {
 	my $self = {};
 	bless $self, $class;
 
-	if (! -f $db_path) {
+	if ($db_path =~ /^:/) {
+		$self->_open_db($db_path);
+		$self->initialize_db();
+	} elsif (! -f $db_path) {
 		# ensure the cache directory exists
 		path($db_path)->parent->mkpath({mode => oct(700)});
 
-		my $db = $self->_open_db($db_path);
+		$self->_open_db($db_path);
 		$self->initialize_db();
 	} else {
 		$self->_open_db($db_path);
@@ -103,21 +105,27 @@ method remove_archive($archive) {
 	}
 
 	my @columns_to_copy = map {'`'._prefix_archive_id($_).'`'} @keep_archives;
+	my @timestamp_columns_to_copy = @columns_to_copy;
 	@columns_to_copy = ('`path`', @columns_to_copy);
-	$self->{dbh}->do('insert into `files_new` select '.join(',', @columns_to_copy).' from files');
+
+	if (@timestamp_columns_to_copy > 0) {
+		$self->{dbh}->do('insert into `files_new` select '.join(',', @columns_to_copy).' from files');
+	}
 
 	$self->{dbh}->do('drop table `files`');
 
 	$self->{dbh}->do('alter table `files_new` rename to `files`');
 
-	my $sql = 'delete from `files` where ';
-	$sql .= join(' is null and ', grep {$_ ne '`path`' } @columns_to_copy);
-	$sql .= " is null";
+	if (@timestamp_columns_to_copy > 0) {
+		my $sql = 'delete from `files` where ';
+		$sql .= join(' is null and ', @timestamp_columns_to_copy);
+		$sql .= " is null";
 
-	my $st = $self->{dbh}->prepare($sql);
-	my $rows = $st->execute();
+		my $st = $self->{dbh}->prepare($sql);
+		$st->execute();
+	}
 
-	$st = $self->{dbh}->prepare('delete from `archives` where `archive_name` = ?;');
+	my $st = $self->{dbh}->prepare('delete from `archives` where `archive_name` = ?;');
 	$st->execute($archive);
 }
 
@@ -153,16 +161,26 @@ method get_archives_for_path($path) {
 	return \@ret;
 }
 
-
-method add_path($archive_id, $path, $time) {
+method _insert_path($archive_id, $path, $time) {
 	my $st = $self->{dbh}->prepare_cached('insert or ignore into `files` (`path`, `'.$archive_id.'`)
 		values(?, ?)');
 	$st->execute($path, $time);
+}
 
-	$st = $self->{dbh}->prepare_cached('update files set `'.$archive_id.'` = ? where `path` = ?');
+method add_path($archive_id, $path, $time) {
+	$self->_insert_path($archive_id, $path, $time);
+
+	my $st = $self->{dbh}->prepare_cached('update files set `'.$archive_id.'` = ? where `path` = ?');
 	$st->execute($time, $path);
 }
 
+method update_path_if_greater($archive_id, $path, $time) {
+	$self->_insert_path($archive_id, $path, $time);
+
+	my $st = $self->{dbh}->prepare_cached('update files set `'.$archive_id.'` = ? where `path` = ? and (`'.$archive_id.'` < ? or `'.$archive_id.'` is null)');
+	$st->execute($time, $path, $time);
+}
+
 method begin_work() {
 	$self->{dbh}->begin_work();
 }
@@ -175,8 +193,8 @@ method verify_cache_fill_rate_ok() {
 	my $used = $self->{dbh}->sqlite_db_status()->{cache_used}->{current};
 	$log->debugf("sqlite page cache usage: %s", format_bytes($used, si=>1));
 	if ($used > $self->{cache_size} * 1024 * 0.95) {
-		$log->warnf("sqlite cache usage is %s of %s", format_bytes($used, si=>1), format_bytes($self->{cache_size} * 1024, si => 1));
-		$log->warn("Consider increasing the sqlite cache (see documentation of App::BorgRestore::Settings)");
+		$log->debugf("sqlite cache usage is %s of %s", format_bytes($used, si=>1), format_bytes($self->{cache_size} * 1024, si => 1));
+		$log->debug("Consider increasing the sqlite cache if you notice performance issues (see documentation of App::BorgRestore::Settings)");
 	}
 }
 
